@@ -1,12 +1,16 @@
 from __future__ import annotations
 
-from typing import Dict, Hashable, List, Mapping, TypeVar
+from typing import Dict, Hashable, List, Mapping, TypeVar, Union
 
 from di.api.scopes import Scope
-from di.exceptions import DuplicateScopeError
+from di.exceptions import DuplicateScopeError, UnknownScopeError
 
 KT = TypeVar("KT", bound=Hashable)
 VT = TypeVar("VT")
+T = TypeVar("T")
+
+
+UNSET = object()
 
 
 class ScopeMap(Dict[Scope, Dict[KT, VT]]):
@@ -25,13 +29,19 @@ class ScopeMap(Dict[Scope, Dict[KT, VT]]):
             res.update(m)
         return res
 
+    def get_from_scope(self, key: KT, *, scope: Scope, default: T) -> Union[VT, T]:
+        try:
+            return self[scope].get(key, default)
+        except KeyError:
+            raise UnknownScopeError(str(scope)) from None
+
     def set(self, key: KT, value: VT, *, scope: Scope) -> None:
         self[scope][key] = value
 
     def add_scope(self, scope: Scope) -> None:
         if scope in self:
             raise DuplicateScopeError(f"The scope {scope} already exists!")
-        self[scope] = {}
+        self[scope] = {}  # type: ignore
 
     def __repr__(self) -> str:  # pragma: no cover, used only for debugging
         values: List[str] = []
