@@ -8,7 +8,6 @@ from contextlib import contextmanager
 from types import TracebackType
 from typing import (
     Any,
-    Collection,
     ContextManager,
     Deque,
     Dict,
@@ -32,10 +31,10 @@ else:
 from graphlib2 import TopologicalSorter
 
 from di._utils.execution_planning import SolvedDependantCache, plan_execution
-from di._utils.inspect import get_type, is_async_gen_callable, is_coroutine_callable
+from di._utils.inspect import get_type
 from di._utils.scope_validation import validate_scopes
 from di._utils.state import ContainerState
-from di._utils.task import AsyncTask, SyncTask
+from di._utils.task import Task
 from di._utils.topsort import topsort
 from di._utils.types import FusedContextManager
 from di.api.dependencies import CacheKey, DependantBase, DependencyParameter
@@ -48,9 +47,7 @@ from di.exceptions import WiringError
 __all__ = ("BaseContainer", "Container")
 
 
-_Task = Union[AsyncTask, SyncTask]
-
-_DependantTaskDag = Dict[_Task, Set[_Task]]
+_DependantTaskDag = Dict[Task, Set[Task]]
 _DependantQueue = Deque[DependantBase[Any]]
 
 
@@ -74,12 +71,16 @@ class _ContainerCommon:
         self,
         scopes: Sequence[Scope],
     ):
-        self._scopes = list(scopes)
+        self._scopes = tuple(scopes)
         self._register_hooks = []
 
     @property
-    def scopes(self) -> Collection[Scope]:
-        return self._state.stacks.keys()
+    def scopes(self) -> Sequence[Scope]:
+        return self._scopes
+
+    @property
+    def current_scopes(self) -> Sequence[Scope]:
+        return tuple(self._state.stacks.keys())
 
     @property
     def _state(self) -> ContainerState:
@@ -215,29 +216,16 @@ class _ContainerCommon:
             }
         )
         # Create a seperate TopologicalSorter to hold the Tasks
-        ts: TopologicalSorter[_Task] = TopologicalSorter()
+        ts: TopologicalSorter[Task] = TopologicalSorter()
         tasks = self._build_tasks(
             computable_param_graph,
             (dependants[key] for key_group in dep_topsort for key in key_group),
             ts,
         )
         ts.prepare()
-        task_dependency_dag: _DependantTaskDag = {
-            tasks[dep.cache_key]: {
-                tasks[predecessor_dep.dependency.cache_key]
-                for predecessor_dep in predecessor_deps
-            }
-            for dep, predecessor_deps in computable_param_graph.items()
-        }
-        call_map: Dict[DependencyProvider, Set[_Task]] = {}
-        for t in task_dependency_dag:
-            if t.call not in call_map:
-                call_map[t.call] = set()
-            call_map[t.call].add(t)
         container_cache = SolvedDependantCache(
             root_task=tasks[dependency.cache_key],
             topological_sorter=ts,
-            callable_to_task_mapping={k: tuple(v) for k, v in call_map.items()},
         )
         validate_scopes(
             self._scopes,
@@ -257,13 +245,13 @@ class _ContainerCommon:
             List[DependencyParameter],
         ],
         topsorted: Iterable[DependantBase[Any]],
-        ts: TopologicalSorter[_Task],
-    ) -> Dict[CacheKey, _Task]:
-        tasks: Dict[CacheKey, _Task] = {}
+        ts: TopologicalSorter[Task],
+    ) -> Dict[CacheKey, Task]:
+        tasks: Dict[CacheKey, Task] = {}
         task_id = 0
         for dep in topsorted:
-            positional: List[_Task] = []
-            keyword: Dict[str, _Task] = {}
+            positional: List[Task] = []
+            keyword: Dict[str, Task] = {}
             for param in dag[dep]:
                 if param.parameter is not None:
                     task = tasks[param.dependency.cache_key]
@@ -276,26 +264,15 @@ class _ContainerCommon:
             keyword_parameters = tuple((k, v) for k, v in keyword.items())
 
             assert dep.call is not None
-            if is_async_gen_callable(dep.call) or is_coroutine_callable(dep.call):
-                tasks[dep.cache_key] = task = AsyncTask(
-                    scope=dep.scope,
-                    call=dep.call,
-                    use_cache=dep.use_cache,
-                    dependant=dep,
-                    task_id=task_id,
-                    positional_parameters=positional_parameters,
-                    keyword_parameters=keyword_parameters,
-                )
-            else:
-                tasks[dep.cache_key] = task = SyncTask(
-                    scope=dep.scope,
-                    call=dep.call,
-                    use_cache=dep.use_cache,
-                    dependant=dep,
-                    task_id=task_id,
-                    positional_parameters=positional_parameters,
-                    keyword_parameters=keyword_parameters,
-                )
+            tasks[dep.cache_key] = task = Task(
+                scope=dep.scope,
+                call=dep.call,
+                use_cache=dep.use_cache,
+                dependant=dep,
+                task_id=task_id,
+                positional_parameters=positional_parameters,
+                keyword_parameters=keyword_parameters,
+            )
             task_id += 1
             ts.add(task, *(tasks[p.dependency.cache_key] for p in dag[dep]))
         return tasks
@@ -350,17 +327,13 @@ class BaseContainer(_ContainerCommon):
     def __init__(
         self,
         *,
-        scopes: Sequence[Scope],
+        scopes: Sequence[Scope] = (None,),
     ) -> None:
         super().__init__(
             scopes=scopes,
         )
         self.__state = ContainerState.initialize()
 
-    @property
-    def scopes(self) -> Collection[Scope]:
-        return self.__state.stacks.keys()
-
     @property
     def _state(self) -> ContainerState:
         return self.__state
@@ -436,7 +409,7 @@ class Container(_ContainerCommon):
     def __init__(
         self,
         *,
-        scopes: Sequence[Scope],
+        scopes: Sequence[Scope] = (None,),
     ) -> None:
         super().__init__(
             scopes=scopes,
@@ -448,10 +421,6 @@ class Container(_ContainerCommon):
     def _state(self) -> ContainerState:
         return self._context.get()
 
-    @property
-    def scopes(self) -> Collection[Scope]:
-        return self._state.stacks.keys()
-
     def copy(self: _ContainerType) -> _ContainerType:
         new = object.__new__(self.__class__)
         new._scopes = self._scopes
